tcpkeepalive

package module
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 23, 2018 License: MIT Imports: 4 Imported by: 1

README

Fine grained tcp keepalive control

Build Status GoDoc

Requirements

golang >= 1.9 (since we use the new syscall.RawConn interface)

TODO

Add support for other OSes (*bsd, darwin etc...).

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetKeepAliveCount

func SetKeepAliveCount(c *net.TCPConn, n int) error

SetKeepAliveCount sets the number of keepalive probes without an acknowledge TCP should send before dropping the connection.

func SetKeepAliveIdle

func SetKeepAliveIdle(c *net.TCPConn, d time.Duration) error

SetKeepAliveIdle sets the time the connection must be idle before keepalive probes are sent.

func SetKeepAliveInterval

func SetKeepAliveInterval(c *net.TCPConn, d time.Duration) error

SetKeepAliveInterval sets the time between keepalive probes.

Types

This section is empty.

Jump to