Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetKeepAliveCount ¶
SetKeepAliveCount sets the number of keepalive probes without an acknowledge TCP should send before dropping the connection.
func SetKeepAliveIdle ¶
SetKeepAliveIdle sets the time the connection must be idle before keepalive probes are sent.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.